autowisp.magnitude_fitting.tests.test_mphotref_collector module — AutoWISP documentation

# autowisp.magnitude_fitting.tests.test_mphotref_collector module

## Class Inheritance Diagram

Define tests to verify master photref collector works correctly.

class autowisp.magnitude_fitting.tests.test_mphotref_collector.TestMphotrefCollector(methodName='runTest')

  Bases: `FloatTestCase`

  Tests of the `MasterPhotrefCollector`.

  _assertMaster(test_master_fname, test_case)

    Assert that the generated master references matches the expected.

  _assertStat(test_stat_fname, test_case, nphot)

    Assert that the generated statistics matches the expected.

  _get_big_catalog()

    Return the catalog to use for the big test.

  _get_collector_inputs_big(img_i)

    Feed the collector with the stars for the big test.

    One out of every 9 catalog stars will never appear in an image (128 stars). Another one out of very 9 catalog stars will only appear in one out of 8 images. Another one of 9 catalog stars will be missing from 1/8th of the images and 768 stars will appear in all images.

    For each star for each photometry one out of 14 images will have outlier flux (different image for different photometry). Ditto for photometry error estimates.

  _get_collector_inputs_rotatestars(img_i)

    Feed the collector with 10 stars, 20 images, 5 photometries.

  _get_collector_inputs_tiny(img_i)

    Feed the collector with 10 stars, 20 images, 5 photometries.

  _get_empty_collector_inputs(test_case)

    Return empty arrays with correct dtype for collector inputs.

  _get_empty_masters(test_name)

    Return properly initalized masters with undefined entries.

  _get_empty_stat(test_case)

    Return empty, but properly configured statistics DataFrame.

  _get_master_big()

    Return the expected master Data Frame for the big test.

  _get_master_rotatestars()

    Return the expected master DataFrame for the rotatestars test.

  _get_rotatestars_catalog()

    Return the catalog to use for the rotatestars test.

  _get_stat_big()

    Return the expected statistics file for the big test.

  _get_stat_rotatestars()

    Return the expected statistics DataFrame for the rotatestars test.

  _get_tiny_catalog()

    Return the catalog to use for the tiny test.

  perform_test(test_name)

    Run a single test.

  test_big()

    Big test.

  test_rotatestars()

    Test with rotating collection of stars between images.

  test_tiny()

    Tiny super-fast test.